@@ -4,11 +4,10 @@ function openai_commands() {
     local task=$(abcli_unpack_keyword $1 help)
 
     if [ $task == "help" ]; then
+        literature_review "$@"
+
+        openai_commands_browse "$@"
         openai_commands_complete "$@"
-
-        abcli_show_usage "@openai dashboard" \
-            "browse OpenAI dashboard."
-
         openai_commands_generate "$@"
         openai_commands_gpt "$@"
         openai_commands_images "$@"
@@ -19,11 +18,6 @@ function openai_commands() {
         return
     fi
 
-    if [ "$task" == "dashboard" ]; then
-        abcli_browse https://beta.openai.com/account/usage
-        return
-    fi
-
     abcli_generic_task \
         plugin=openai_commands,task=$task \
         "${@:2}"
@@ -31,6 +25,8 @@ function openai_commands() {
 
 abcli_source_path - caller,suffix=/tests
 
+abcli_log $(openai_commands version --show_icon 1)
+
 abcli_env dot load \
     plugin=openai_commands
 abcli_env dot load \
